@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -23,7 +23,7 @@ class X:
         print "X.__del__ occurred"
 
 def raising(doit):
-    x = X()
+    _x = X()
 
     if doit:
         1 / 0
